@@ -168,6 +168,10 @@ class TgWrap():
 
             # Read the directed graph and reverse it
             graph = nx.DiGraph(nx.nx_pydot.read_dot(f.name)).reverse()
+        except TypeError as e:
+            self.printer.error('terragrunt has problems generating the graph, check the dependencies please!')
+            self.printer.error("once fixed, you can run 'tgwrap show-graph' to verify.")
+            raise click.ClickException(e)
         except Exception as e:
             self.printer.error(e)
             raise click.ClickException(e)
@@ -297,7 +301,6 @@ class TgWrap():
             if response.lower() != "y":
                 sys.exit(1)
 
-        stop_processing = False
         nbr_of_groups = len(groups)
         for idx, group in enumerate(groups):
             group_nbr=idx+1
@@ -325,14 +328,11 @@ class TgWrap():
                     )
 
                     if stop_processing:
-                        self.printer.normal(f"Processing aborted at step {group_nbr}.{module_nbr}.")
+                        self.printer.warning(f"Processing needs to be stopped at step {group_nbr}.{module_nbr}.")
                         self.printer.normal(
                             f"After you've fixed the problem, you can continue where you were left by adding '--start-at-step {group_nbr}.{module_nbr}'."
                             )
-                        break
-
-            if stop_processing:
-                break
+                        sys.exit(1)
         
         self.printer.verbose(f'Executed {group_nbr} groups and {step_nbr} steps')
 
